summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorAlex Solomes <alex.solomes@softwareag.com>2022-05-20 18:46:27 +0100
committerGitHub <noreply@github.com>2022-05-20 18:46:27 +0100
commit30efb357aca2f6fd446336713629ab1d6f0d38dc (patch)
tree9201d22a9aee2abb2befd8de601e707305e318ae
parent824c154a9063dea4dd34e004e27888627d78f29e (diff)
parentdf1731def6ed5893ac8c3f46445e6f23c79b4dd9 (diff)
Merge pull request #1152 from initard/improvement/1077/logfile-management-workflow-fix
update rename of c8y_log_plugin #1077
-rw-r--r--.github/workflows/build-workflow.yml12
-rw-r--r--.github/workflows/ci_pipeline.yml22
-rw-r--r--.github/workflows/integration-test-workflow.yml4
-rw-r--r--.github/workflows/system-test-offsite.yml2
-rw-r--r--configuration/contrib/operations/c8y/c8y_LogfileRequest4
-rwxr-xr-xget-thin-edge_io.sh6
6 files changed, 23 insertions, 27 deletions
diff --git a/.github/workflows/build-workflow.yml b/.github/workflows/build-workflow.yml
index 5dab9ff6..7981e53d 100644
--- a/.github/workflows/build-workflow.yml
+++ b/.github/workflows/build-workflow.yml
@@ -75,12 +75,12 @@ jobs:
command: deb
args: -p tedge_agent
- - name: Build tedge_logfile_request_plugin debian package
+ - name: Build c8y_log_plugin debian package
uses: actions-rs/cargo@v1
# https://github.com/marketplace/actions/rust-cargo
with:
command: deb
- args: -p tedge_logfile_request_plugin
+ args: -p c8y_log_plugin
- name: Build c8y_configuration_plugin debian package
uses: actions-rs/cargo@v1
@@ -201,8 +201,8 @@ jobs:
- name: Strip tedge_apama_plugin
run: arm-linux-gnueabihf-strip target/${{ matrix.target }}/release/tedge_apama_plugin || aarch64-linux-gnu-strip target/${{ matrix.target }}/release/tedge_apama_plugin
- - name: Strip tedge_logfile_request_plugin
- run: arm-linux-gnueabihf-strip target/${{ matrix.target }}/release/tedge_logfile_request_plugin || aarch64-linux-gnu-strip target/${{ matrix.target }}/release/tedge_logfile_request_plugin
+ - name: Strip c8y_log_plugin
+ run: arm-linux-gnueabihf-strip target/${{ matrix.target }}/release/c8y_log_plugin || aarch64-linux-gnu-strip target/${{ matrix.target }}/release/c8y_log_plugin
- name: Strip c8y_configuration_plugin
run: arm-linux-gnueabihf-strip target/${{ matrix.target }}/release/c8y_configuration_plugin || aarch64-linux-gnu-strip target/${{ matrix.target }}/release/c8y_configuration_plugin
@@ -242,12 +242,12 @@ jobs:
command: deb
args: -p tedge_apama_plugin --no-strip --no-build --target=${{ matrix.target }}
- - name: build tedge_logfile_request_plugin debian package for target
+ - name: build c8y_log_plugin debian package for target
uses: actions-rs/cargo@v1
# https://github.com/marketplace/actions/rust-cargo
with:
command: deb
- args: -p tedge_logfile_request_plugin --no-strip --no-build --target=${{ matrix.target }}
+ args: -p c8y_log_plugin --no-strip --no-build --target=${{ matrix.target }}
- name: build c8y_configuration_plugin debian package for target
uses: actions-rs/cargo@v1
diff --git a/.github/workflows/ci_pipeline.yml b/.github/workflows/ci_pipeline.yml
index 70747c33..aed831e3 100644
--- a/.github/workflows/ci_pipeline.yml
+++ b/.github/workflows/ci_pipeline.yml
@@ -191,12 +191,12 @@ jobs:
command: deb
args: -p tedge_agent
- - name: Build tedge_logfile_request_plugin debian package
+ - name: Build c8y_log_plugin debian package
uses: actions-rs/cargo@v1
# https://github.com/marketplace/actions/rust-cargo
with:
command: deb
- args: -p tedge_logfile_request_plugin
+ args: -p c8y_log_plugin
- name: Build c8y_configuration_plugin debian package
uses: actions-rs/cargo@v1
@@ -316,8 +316,8 @@ jobs:
- name: Strip tedge_apama_plugin
run: arm-linux-gnueabihf-strip target/${{ matrix.target }}/release/tedge_apama_plugin || aarch64-linux-gnu-strip target/${{ matrix.target }}/release/tedge_apama_plugin
- - name: Strip tedge_logfile_request_plugin
- run: arm-linux-gnueabihf-strip target/${{ matrix.target }}/release/tedge_logfile_request_plugin || aarch64-linux-gnu-strip target/${{ matrix.target }}/release/tedge_logfile_request_plugin
+ - name: Strip c8y_log_plugin
+ run: arm-linux-gnueabihf-strip target/${{ matrix.target }}/release/c8y_log_plugin || aarch64-linux-gnu-strip target/${{ matrix.target }}/release/c8y_log_plugin
- name: Strip c8y_configuration_plugin
run: arm-linux-gnueabihf-strip target/${{ matrix.target }}/release/c8y_configuration_plugin || aarch64-linux-gnu-strip target/${{ matrix.target }}/release/c8y_configuration_plugin
@@ -357,12 +357,12 @@ jobs:
command: deb
args: -p tedge_apama_plugin --no-strip --no-build --target=${{ matrix.target }}
- - name: build tedge_logfile_request_plugin debian package for target
+ - name: build c8y_log_plugin debian package for target
uses: actions-rs/cargo@v1
# https://github.com/marketplace/actions/rust-cargo
with:
command: deb
- args: -p tedge_logfile_request_plugin --no-strip --no-build --target=${{ matrix.target }}
+ args: -p c8y_log_plugin --no-strip --no-build --target=${{ matrix.target }}
- name: build c8y_configuration_plugin debian package for target
uses: actions-rs/cargo@v1
@@ -444,7 +444,7 @@ jobs:
continue-on-error: true
- name: purge
- run: sudo dpkg -P c8y_configuration_plugin tedge_agent tedge_logfile_request_plugin tedge_mapper tedge_apt_plugin tedge_apama_plugin tedge mosquitto libmosquitto1 collectd-core
+ run: sudo dpkg -P c8y_configuration_plugin tedge_agent c8y_log_plugin tedge_mapper tedge_apt_plugin tedge_apama_plugin tedge mosquitto libmosquitto1 collectd-core
- name: install mosquitto
run: sudo apt-get --assume-yes install mosquitto
@@ -587,7 +587,7 @@ jobs:
continue-on-error: true
- name: purge
- run: sudo dpkg -P c8y_configuration_plugin tedge_agent tedge_logfile_request_plugin tedge_mapper tedge_apt_plugin tedge_apama_plugin tedge mosquitto-clients mosquitto libmosquitto1 collectd-core collectd
+ run: sudo dpkg -P c8y_configuration_plugin tedge_agent c8y_log_plugin tedge_mapper tedge_apt_plugin tedge_apama_plugin tedge mosquitto-clients mosquitto libmosquitto1 collectd-core collectd
- name: install mosquitto
run: sudo apt-get --assume-yes install mosquitto
@@ -711,7 +711,7 @@ jobs:
continue-on-error: true
- name: purge
- run: sudo dpkg -P c8y_configuration_plugin tedge_agent tedge_logfile_request_plugin tedge_mapper tedge_apt_plugin tedge_apama_plugin tedge mosquitto-clients mosquitto libmosquitto1 collectd-core collectd
+ run: sudo dpkg -P c8y_configuration_plugin tedge_agent c8y_log_plugin tedge_mapper tedge_apt_plugin tedge_apama_plugin tedge mosquitto-clients mosquitto libmosquitto1 collectd-core collectd
- name: install mosquitto
run: sudo apt-get --assume-yes install mosquitto
@@ -836,7 +836,7 @@ jobs:
continue-on-error: true
- name: purge
- run: sudo dpkg -P c8y_configuration_plugin tedge_agent tedge_logfile_request_plugin tedge_mapper tedge_apt_plugin tedge_apama_plugin tedge mosquitto-clients mosquitto libmosquitto1 collectd-core collectd
+ run: sudo dpkg -P c8y_configuration_plugin tedge_agent c8y_log_plugin tedge_mapper tedge_apt_plugin tedge_apama_plugin tedge mosquitto-clients mosquitto libmosquitto1 collectd-core collectd
- name: install mosquitto
run: sudo apt-get --assume-yes install mosquitto
@@ -961,7 +961,7 @@ jobs:
continue-on-error: true
- name: purge
- run: sudo dpkg -P c8y_configuration_plugin tedge_agent tedge_logfile_request_plugin tedge_mapper tedge_apt_plugin tedge_apama_plugin tedge mosquitto-clients mosquitto libmosquitto1 collectd-core collectd
+ run: sudo dpkg -P c8y_configuration_plugin tedge_agent c8y_log_plugin tedge_mapper tedge_apt_plugin tedge_apama_plugin tedge mosquitto-clients mosquitto libmosquitto1 collectd-core collectd
- name: install mosquitto
run: sudo apt-get --assume-yes install mosquitto
diff --git a/.github/workflows/integration-test-workflow.yml b/.github/workflows/integration-test-workflow.yml
index 58202f25..9a2f393d 100644
--- a/.github/workflows/integration-test-workflow.yml
+++ b/.github/workflows/integration-test-workflow.yml
@@ -46,7 +46,7 @@ jobs:
continue-on-error: true
- name: purge
- run: sudo dpkg -P c8y_configuration_plugin tedge_agent tedge_logfile_request_plugin tedge_mapper tedge_apt_plugin tedge_apama_plugin tedge mosquitto libmosquitto1 collectd-core
+ run: sudo dpkg -P c8y_configuration_plugin tedge_agent c8y_log_plugin tedge_mapper tedge_apt_plugin tedge_apama_plugin tedge mosquitto libmosquitto1 collectd-core
- name: install mosquitto
run: sudo apt-get --assume-yes install mosquitto
@@ -200,7 +200,7 @@ jobs:
# mosquitto-clients is required for system test only, but has dependency on libmosquitto1.
# therefore, we need to purge it here, and mosquitto-clients is required only for RPi.
- name: purge
- run: sudo dpkg -P c8y_configuration_plugin tedge_agent tedge_logfile_request_plugin tedge_mapper tedge_apt_plugin tedge_apama_plugin tedge mosquitto-clients mosquitto libmosquitto1 collectd-core collectd
+ run: sudo dpkg -P c8y_configuration_plugin tedge_agent c8y_log_plugin tedge_mapper tedge_apt_plugin tedge_apama_plugin tedge mosquitto-clients mosquitto libmosquitto1 collectd-core collectd
- name: install mosquitto
run: sudo apt-get --assume-yes install mosquitto
diff --git a/.github/workflows/system-test-offsite.yml b/.github/workflows/system-test-offsite.yml
index 76fc53b9..b18fcf5e 100644
--- a/.github/workflows/system-test-offsite.yml
+++ b/.github/workflows/system-test-offsite.yml
@@ -52,7 +52,7 @@ jobs:
path: /home/pi/examples
- name: purge packages
- run: sudo dpkg -P c8y_configuration_plugin tedge_agent tedge_logfile_request_plugin tedge_mapper tedge_apt_plugin tedge_apama_plugin tedge mosquitto-clients mosquitto libmosquitto1 collectd-core collectd
+ run: sudo dpkg -P c8y_configuration_plugin tedge_agent c8y_log_plugin tedge_mapper tedge_apt_plugin tedge_apama_plugin tedge mosquitto-clients mosquitto libmosquitto1 collectd-core collectd
- name: install packages
run: sudo apt-get --assume-yes install mosquitto-clients mosquitto libmosquitto1 collectd-core collectd
diff --git a/configuration/contrib/operations/c8y/c8y_LogfileRequest b/configuration/contrib/operations/c8y/c8y_LogfileRequest
deleted file mode 100644
index b30c550d..00000000
--- a/configuration/contrib/operations/c8y/c8y_LogfileRequest
+++ /dev/null
@@ -1,4 +0,0 @@
-[exec]
-topic = "c8y/s/ds"
-on_message = "522"
-command = "/usr/bin/tedge_logfile_request_plugin"
diff --git a/get-thin-edge_io.sh b/get-thin-edge_io.sh
index 11edf985..af1757b2 100755
--- a/get-thin-edge_io.sh
+++ b/get-thin-edge_io.sh
@@ -41,9 +41,9 @@ install_tedge_plugins() {
wget https://github.com/thin-edge/thin-edge.io/releases/download/${VERSION}/tedge_apama_plugin_${VERSION}_${ARCH}.deb -P /tmp/tedge
dpkg -i /tmp/tedge/tedge_apama_plugin_${VERSION}_${ARCH}.deb
- # Download and install logfile plugin
- wget https://github.com/thin-edge/thin-edge.io/releases/download/${VERSION}/tedge_logfile_request_plugin_${VERSION}_${ARCH}.deb -P /tmp/tedge
- dpkg -i /tmp/tedge/tedge_logfile_request_plugin_${VERSION}_${ARCH}.deb
+ # Download and install c8y log plugin
+ wget https://github.com/thin-edge/thin-edge.io/releases/download/${VERSION}/c8y_log_plugin_${VERSION}_${ARCH}.deb -P /tmp/tedge
+ dpkg -i /tmp/tedge/c8y_log_plugin_${VERSION}_${ARCH}.deb
# Download and install configuration plugin
wget https://github.com/thin-edge/thin-edge.io/releases/download/${VERSION}/c8y_configuration_plugin_${VERSION}_${ARCH}.deb -P /tmp/tedge